# systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

Summary: Scanmonitord monitors scanner buttons and sensors
Name: scanmonitord
Version: 1.8.6
Release: 1%{?dist}
License: GPL-2.0-or-later
Group: Applications/System
URL: http://www.invoca.ch/pub/packages/scanmonitord/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: %{name}-%{version}.tar.gz
Source1: %{name}.%{_servicefile_postfix}
%if %{_has_systemd}
Source2: %{name}-tmpfiles.conf
BuildRequires: systemd, sed
%systemd_requires
%else
Requires(pre,postun): /sbin/service
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
%endif
BuildRequires: sane-backends-devel, gcc
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
Scanmonitord is a daemon which runs device monitors on one or more devices.
Every button or sensor event is then evaluated by user generated action
scripts which can itself call whatever system command they want.
For postprocessing scanned images, scanmonitord has the ability
to start image processing scripts as daemons which can automate additional
actions like OCR on scanned images by user defined scripts.

%prep
%setup -q
%if %{_has_systemd}
%{__sed} -i -e "s@\/var\/run\/@%{_pidbasedir}/@g" src/%{name}.sh
%endif

%build
%{__cc} %{optflags} $(sane-config --libs -cflags) -o bin/%{name}-sanebd src/%{name}-sanebd.c

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sysconfdir}/%{name}.d
%{__install} -d %{buildroot}%{_bindir}
%{__install} -d %{buildroot}%{_exec_prefix}/lib/%{name}
%{__install} -d -m 0775 %{buildroot}%{_pidbasedir}/%{name}

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p conf/%{name}.conf %{buildroot}%{_sysconfdir}/
%{__install} -m 0755 -p src/%{name}.sh %{buildroot}%{_bindir}/%{name}
%{__install} -m 0755 -p bin/%{name}-sanebd %{buildroot}%{_bindir}/
%{__install} -m 0644 -p lib/%{name}-* %{buildroot}%{_exec_prefix}/lib/%{name}/

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
%if ! %{_has_systemd}
# let postun know whether we were running
if [ -e /var/lock/subsys/%{name} ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  sleep 1
  %{__rm} -f %{_pidbasedir}/%{name}/%{name}.pid
  touch /var/lock/subsys/%{name}
fi
%endif

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc ChangeLog LICENSE README samples/
%config(noreplace) %{_sysconfdir}/%{name}.conf
%dir %{_sysconfdir}/%{name}.d
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%else
%config %{_initrddir}/%{name}
%endif
%{_bindir}/%{name}
%{_bindir}/%{name}-*
%dir %{_exec_prefix}/lib/%{name}
%{_exec_prefix}/lib/%{name}/%{name}-*
%dir %attr(0775,root,root) %verify(not group) %{_pidbasedir}/%{name}

%changelog
* Fri May 16 2025 Simon Matter <simon.matter@invoca.ch> 1.8.6-1
- upgrade to 1.8.6

* Thu Jul 20 2023 Simon Matter <simon.matter@invoca.ch> 1.8.5-2
- change to *.common.service systemd files
- remove eval where possible
- change to SPDX license tag

* Thu Sep 30 2021 Simon Matter <simon.matter@invoca.ch> 1.8.5-1
- upgrade to 1.8.5

* Wed Sep 29 2021 Simon Matter <simon.matter@invoca.ch> 1.8.4-1
- upgrade to 1.8.4

* Wed Sep 29 2021 Simon Matter <simon.matter@invoca.ch> 1.8.3-1
- upgrade to 1.8.3

* Tue Sep 28 2021 Simon Matter <simon.matter@invoca.ch> 1.8.2-1
- upgrade to 1.8.2

* Mon Sep 27 2021 Simon Matter <simon.matter@invoca.ch> 1.8.1-1
- upgrade to 1.8.1

* Thu Sep 23 2021 Simon Matter <simon.matter@invoca.ch> 1.8.0-1
- upgrade to 1.8.0

* Wed Sep 22 2021 Simon Matter <simon.matter@invoca.ch> 1.7.4-1
- upgrade to 1.7.4

* Tue Sep 21 2021 Simon Matter <simon.matter@invoca.ch> 1.7.3-1
- upgrade to 1.7.3

* Tue Sep 21 2021 Simon Matter <simon.matter@invoca.ch> 1.7.2-1
- upgrade to 1.7.2

* Mon Sep 20 2021 Simon Matter <simon.matter@invoca.ch> 1.7.1-1
- upgrade to 1.7.1

* Mon Sep 20 2021 Simon Matter <simon.matter@invoca.ch> 1.7.0-1
- upgrade to 1.7.0

* Wed Jun 08 2021 Simon Matter <simon.matter@invoca.ch> 1.6.9-1
- upgrade to 1.6.9

* Wed Apr 15 2020 Simon Matter <simon.matter@invoca.ch> 1.6.8-2
- add support for EL8

* Thu Feb 07 2019 Simon Matter <simon.matter@invoca.ch> 1.6.8-1
- upgrade to 1.6.8

* Thu Mar 22 2018 Simon Matter <simon.matter@invoca.ch> 1.6.7-1
- upgrade to 1.6.7

* Fri Mar 09 2018 Simon Matter <simon.matter@invoca.ch> 1.6.6-1
- upgrade to 1.6.6

* Thu Mar 08 2018 Simon Matter <simon.matter@invoca.ch> 1.6.5-1
- upgrade to 1.6.5

* Fri Sep 08 2017 Simon Matter <simon.matter@invoca.ch> 1.6.4-1
- upgrade to 1.6.4

* Wed Sep 06 2017 Simon Matter <simon.matter@invoca.ch> 1.6.3-1
- upgrade to 1.6.3

* Tue Sep 05 2017 Simon Matter <simon.matter@invoca.ch> 1.6.2-1
- upgrade to 1.6.2

* Thu May 28 2015 Simon Matter <simon.matter@invoca.ch> 1.6.1-1
- upgrade to 1.6.1

* Wed May 20 2015 Simon Matter <simon.matter@invoca.ch> 1.6.0-1
- upgrade to 1.6.0

* Tue May 19 2015 Simon Matter <simon.matter@invoca.ch> 1.5.2-1
- upgrade to 1.5.2

* Tue May 19 2015 Simon Matter <simon.matter@invoca.ch> 1.5.1-1
- upgrade to 1.5.1

* Tue May 19 2015 Simon Matter <simon.matter@invoca.ch> 1.5.0-1
- upgrade to 1.5.0

* Mon May 18 2015 Simon Matter <simon.matter@invoca.ch> 1.4.1-1
- upgrade to 1.4.1

* Sat May 16 2015 Simon Matter <simon.matter@invoca.ch> 1.4.0-1
- upgrade to 1.4.0

* Fri May 15 2015 Simon Matter <simon.matter@invoca.ch> 1.3.3-1
- upgrade to 1.3.3

* Fri May 15 2015 Simon Matter <simon.matter@invoca.ch> 1.3.2-1
- upgrade to 1.3.2

* Fri May 15 2015 Simon Matter <simon.matter@invoca.ch> 1.3.1-1
- upgrade to 1.3.1

* Wed May 13 2015 Simon Matter <simon.matter@invoca.ch> 1.3.0-1
- upgrade to 1.3.0
- add support for systemd

* Wed Aug 28 2013 Simon Matter <simon.matter@invoca.ch> 1.2.7-1
- upgrade to 1.2.7

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 1.2.6-2
- mass rebuild

* Wed Jul 28 2010 Simon Matter <simon.matter@invoca.ch> 1.2.6-1
- upgrade to 1.2.6

* Sat Jul 24 2010 Simon Matter <simon.matter@invoca.ch> 1.2.5-1
- upgrade to 1.2.5

* Fri Jul 23 2010 Simon Matter <simon.matter@invoca.ch> 1.2.4-1
- upgrade to 1.2.4
- change spec file to force service stop before upgrade

* Fri Jul 23 2010 Simon Matter <simon.matter@invoca.ch> 1.2.3-1
- upgrade to 1.2.3

* Tue Mar 17 2009 Simon Matter <simon.matter@invoca.ch> 1.2.2-2
- add missing pre/post requirements

* Wed Mar 04 2009 Simon Matter <simon.matter@invoca.ch> 1.2.2-1
- upgrade to 1.2.2

* Sat Feb 28 2009 Simon Matter <simon.matter@invoca.ch> 1.2.1-1
- upgrade to 1.2.1

* Fri Feb 27 2009 Simon Matter <simon.matter@invoca.ch> 1.2.0-1
- upgrade to 1.2.0

* Fri Feb 27 2009 Simon Matter <simon.matter@invoca.ch> 1.1.7-1
- upgrade to 1.1.7

* Thu Feb 26 2009 Simon Matter <simon.matter@invoca.ch> 1.1.6-1
- upgrade to 1.1.6

* Fri Feb 20 2009 Simon Matter <simon.matter@invoca.ch> 1.1.5-1
- upgrade to 1.1.5

* Wed Feb 18 2009 Simon Matter <simon.matter@invoca.ch> 1.1.4-1
- upgrade to 1.1.4

* Tue Feb 17 2009 Simon Matter <simon.matter@invoca.ch> 1.1.3-1
- upgrade to 1.1.3

* Tue Feb 03 2009 Simon Matter <simon.matter@invoca.ch> 1.1.2-1
- upgrade to 1.1.2

* Fri Jan 30 2009 Simon Matter <simon.matter@invoca.ch> 1.1.1-1
- upgrade to 1.1.1

* Thu Jan 29 2009 Simon Matter <simon.matter@invoca.ch> 1.1.0-1
- upgrade to 1.1.0

* Mon Jan 26 2009 Simon Matter <simon.matter@invoca.ch> 1.0.2-1
- upgrade to 1.0.2

* Sat Jan 24 2009 Simon Matter <simon.matter@invoca.ch> 1.0.0-1
- upgrade to 1.0.0

* Fri Jan 23 2009 Simon Matter <simon.matter@invoca.ch> 0.3.4-1
- upgrade to 0.3.4

* Fri Jan 16 2009 Simon Matter <simon.matter@invoca.ch> 0.3.1-1
- upgrade to 0.3.1

* Thu Jan 15 2009 Simon Matter <simon.matter@invoca.ch> 0.3.0-1
- upgrade to 0.3.0

* Wed Jan 07 2009 Simon Matter <simon.matter@invoca.ch> 0.2.5-1
- upgrade to 0.2.5

* Mon Dec 22 2008 Simon Matter <simon.matter@invoca.ch> 0.2.4-1
- upgrade to 0.2.4

* Thu Nov 27 2008 Simon Matter <simon.matter@invoca.ch> 0.2.3-1
- upgrade to 0.2.3

* Wed Nov 26 2008 Simon Matter <simon.matter@invoca.ch> 0.2.2-1
- upgrade to 0.2.2

* Fri Oct 31 2008 Simon Matter <simon.matter@invoca.ch> 0.2.1-1
- upgrade to 0.2.1

* Fri Oct 31 2008 Simon Matter <simon.matter@invoca.ch> 0.2.0-1
- upgrade to 0.2.0

* Thu Oct 02 2008 Simon Matter <simon.matter@invoca.ch> 0.1.7-1
- upgrade to 0.1.7

* Wed Oct 01 2008 Simon Matter <simon.matter@invoca.ch> 0.1.6-1
- upgrade to 0.1.6

* Fri Sep 26 2008 Simon Matter <simon.matter@invoca.ch> 0.1.5-1
- upgrade to 0.1.5

* Thu Sep 25 2008 Simon Matter <simon.matter@invoca.ch> 0.1.4-1
- upgrade to 0.1.4

* Thu Sep 18 2008 Simon Matter <simon.matter@invoca.ch> 0.1.0-1
- initial package
